# Nexstar Python API

This code follows the NexStar Communication Protocol as described in NexStarCommunicationProtocolV1.2.pdf

This latest version of this code is located at https://github.com/circuitqed/nexstar

This code is forked from https://github.com/sidneycadot/nexstar

The main class is NexstarHandController and supports the following methods:

* getAlignmentComplete
* getDeviceVersion
* getGotoInProgress
* getLocation
* getModel
* getPosition
* getTime
* getTrackingMode
* getVersion
* gotoPosition
* passthrough
* setLocation
* setTime
* setTrackingMode
* slew_fixed
* slew_variable
